Framkvæmd á áhættumati með OiRA | OiRA

Þemu

# Framkvæmd á áhættumati með OiRA

## Hefja nýja lotu

Til að byrja nýtt áhættumat skaltu smella á hlekkinn „hefja nýja lotu“.

## Opna áhættumat

Þegar þú hefur byrjað áhættumat getur þú farið aftur á það hvenær sem er á stjórnborðinu undir fyrirsögninni „áhættumötin mín“. Þaðan getur þú líka byrjað nýtt áhættumat.

Stjórnborðið.

## Stikað um áhættumat

Hvert áhættumat leiðir þig í gegnum fjölmörg skref. Þau má sjá í aðalvalmyndinni til vinstri á skjánum:

- Undirbúningur
- Þátttaka
- Greining + Mat
- Aðgerðaáætlun
- Skýrsla
- Staða

Uppbygging viðkomandi verkfæris fer eftir ákvörðunum landsskrifstofu OiRA/hugbúnaðarhönnuðarins. Í sumum verkfærum er aðgerðaráætlunina að finna í greiningar- og matsskrefinu. Í slíkum tilvikum birtist valmyndin til vinstri með eftirfarandi hætti:

- Undirbúningur
- Þátttaka
- Mat
- Skýrsla
- Staða

## Undirbúningur

„Undirbúningur“ er þar sem þú byrjar hverja lotu/verkfæri. Þar gefur þú áhættumatinu nafn sem síðar mun hjálpa þér við að greina á milli mismunandi áhættumata sem þú hefur búið til í verkfærinu.

Hlekkurinn „Frekari upplýsingar um verkfærið…“ veitir frekari upplýsingar um valið verkfæri og þá sem tóku þátt í þróun þess.

Þegar þú hefur smellt á „Byrja“ getur verið að aukalegar spurningar birtist, það fer allt eftir verkfærinu sem þú ert að nota. Þessi undirbúningsskjámynd með „spurningum“ birtist aðeins hjá verkfærum sem bjóða upp á slíkt.

Hér getur þú:

- Valið eða hoppað yfir aðstæður eftir því hvort þær eiga við reksturinn þinn. Valið „já“ þar sem við á.
- Skráð rekstrareiningar, útibú eða búðir o.s.frv. Tengd áhætta verður endurtekin fyrir allar einingarnar sem þú skráðir.

The “Profile” screen in the Preparation step

Undirbúningsskrefið er mjög mikilvægt því þar skilgreinir þú rekstur þinn með nákvæmum hætti og tengda áhættu sem fyrirtækið þitt stendur frammi fyrir. Eftir að þú hefur smellt á „vista og halda áfram“ ferðu yfir í næsta hluta, „þátttaka“.

Athugaðu: Mörg verkfæri búa ekki yfir upphafsspurningunum því þær nota þær ekki til að sérsníða verkfærið. Við slíkar aðstæður er hoppað sjálfkrafa yfir þessa skjámynd.

## Þátttaka

Þetta skref er áminning um mikilvægi þess að starfsmenn taki þátt og sýnir hvernig tryggja megi þátttöku starfsmanna með mismunandi hætti. Hér getur þú sótt eða prentað út innihald áhættumatsins til að deila með launþegum/starfsmönnum þínum. Það tryggir að launþegar geti tekið þátt í mati á aðstæðum á vinnustað sínum.

## Mat

Í þessu skrefi leggur þú mat á hættur og vandamál í fyrirtækinu þínu.

Athugaðu: Það fer eftir því hvernig viðkomandi samstarfsaðili OiRA setti upp verkærið hvort skrefið „aðgerðaáætlun“ (sjá að neðan) er hluti af þessari skjámynd. Í slíku tilviki er allt skrefið nefnt „mat“ og liðirnir, sem fjallað er um í „aðgerðaáætlun“ munu birtast í greiningu og mati á hverri áhættu.

Greining og mat.

Til vinstri á skjánum, undir „greining ´mat“/„mat“ sérðu öll efnisatriðin/áfangana sem finna má í verkfærinu. Efnisatriðin, sem þú ert að skoða, eru auðkennd.

### Greining

Þú þarft að ákveða fyrir hverja áhættu hvort fullyrðingin um tiltekið ástand eigi við um fyrirtækið þitt. Þú getur svarað með eftirfarandi hætti:

- Já: ef þú svarar fullyrðingunni með „já“ er ekki þörf á frekari aðgerðum því þú hefur metið sem svo að áhættan sé ekki til staðar.
- Nei: ef þú svarar fullyrðingunni með „nei“ er þörf á frekari aðgerðum. Þú verður beðinn um að ákveða tilteknar ráðstafanir.
- Á ekki við: sumar áhættufullyrðingar bjóða upp á valkostinn „á ekki við“ ef áhættan á ekki við fyrirtækið þitt.

Undir hverri fullyrðingu er venjulega að finna frekari upplýsingar um tiltekna áhættu:

- Upplýsingar: stutt lýsing, stundum með myndum með frekari upplýsingum um áhættuna.
- Úrræði: aukalegar upplýsingar um áhættuna, eins og tilvísanir til laga og stefna. Stundum getur þú einnig fundið hér viðhengd skjöl til að lesa fyrir frekari upplýsingar.
- Athugasemdir: þú getur skráð eigin athugasemdir hér sem munu birtast í skýrslunni þinni í lok matsins.

Þegar þú hefur svarað áhættufullyrðingu og haldið áfram mun valmyndin til vinstri uppfærast með lituðu tákni sem gefur til kynna hvort þú hafir:

- svarað jákvætt (grænt hakmerki)
- svarað neikvætt (rauður kross)
- frestað (appelsínugult spurningamerki)

Gráta táknið helst fyrir ósvaraðar spurningar.

### Mat

Í þessu skrefi leggur þú mat á forgang áhættu sem þú hefur borið kennsl á.

Evaluating a risk.

Athugaðu: Í sumum OiRA-verkfærum er matið ekki sýnt. Það fer eftir því hvernig landsskrifstofan/OiRA hugbúnaðarhönnuðurinn hefur sett upp viðkomandi OiRA-verkfæri.

Ef þú hefur greint áhættu til staðar (sýnt með rauðum krossi) mun matshlutinn birtast. Eftir matsaðferðinni, sem valin hefur verið fyrir hverja áhættu, verður þú beðin/n um að:

- leggja mat á forganginn: hár, meðalhár eða lágur

Setting the priority of a risk.

EÐA

- svara nokkrum spurningum um tíðni, alvarleika og líkur á áhættunni svo að hægt sé að reikna út forganginn út frá svörum þínum.

Setting variables for a risk.

### Forgangsáhættutegundir sem atvinnugrein hefur valið:

Sumar áhættutegundir eru taldar mjög mikilvægar af landsskrifstofunni/hugbúnaðarhönnuðinum sem bjó til viðkomandi OiRA verkfæri. Þú þarft ekki að leggja mat á slíkar „forgangsáhættutegundir“ því forgangur þeirra er sjálfkrafa stilltur á „hátt“.

Priority risks.

### Sérsniðnar áhættutegundir

Þegar þú hefur svarað öllum áhættuefnisatriðunum í „greining + mat“/„mat“ ferðu í valkvæða efnisatriðið „önnur áhætta“. Hér getur þú með hnappinum“bæta við sérsniðinni áhættu“ bætt við eigin færslum.

Ef áhættu vantar í verkfærinu, sem er til staðar á vinnustaðnum þínum/í fyrirtækinu þínu, þarftu að bæta henni við hér. Þú getur skilgreint/orðað þessar áhættutegundir algjörlega sjálf/ur.

Custom risks.

„Sérsniðin áhætta“ virkar með nánast sama hætti og áhættutegundirnar í OiRA verkfærinu nema þú þarft augljóslega að skrifa textann. Textinn ætti hið minnsta að vera stutt fullyrðing sem lýsir vandamálinu en einnig er kostur á lengri lýsingu. Þú getur einnig hlaðið upp mynd til að sýna tilteknar aðstæður.

Eins og hjá venjulegri áhættu þarftu að segja til um hvort áhættan sé til staðar eða ekki. Það gerir þér kleift að haka við sérsniðna áhættu, þegar þú hefur tekist á við hana með árangri en skrásett hana í áhættumatinu.

Þú getur bætt við eins mörgum sérsniðnum áhættutegundum og þú þarft.

Add a custom risk.

#Aðgerðaráætlun

Í þessu skrefi ákveður þú til hvaða ráðstafana þú vilt grípa til að útrýma eða draga úr áhættu sem þú hefur áður greint.

Athugaðu: Eins og tekið var fram að ofan er aðgerðaáætlunin sett fram í sérstöku skrefi í valmyndinni til vinstri eða birtist undir greindri áhættu. Við hið síðarnefnda nefnist skrefið í valmyndinni „mat“ og inniheldur bæði áhættufullyrðingar og val um viðbrögð.

Útgáfan þín fer eftir ákvörðunum landsskrifstofu OiRA/hönnuði verkfærisins.

### Samþætt aðgerðaáætlun

Integrated action plan.

Ef þú svarar spurningu með „nei“ að þá mun aðgerðaáætlunaráfanginn opnast á síðunni undir fyrirsögninni „ráðstafanir“.

Þú getur bæði valið ráðstafanir af lista, sem kerfið leggur til, eða tilgreint eigin ráðstafanir.

### Aðskilin aðgerðaáætlun

When the action plan is a separate step, it will be accessible through the left hand navigation.

Smelltu á hnappinn „búa til aðgerðaáætlun“ til að búa til áætlunina.

Í skrefinu aðgerðaáætlun sýnir valmyndin til vinstri nú aðeins áhættu, sem merkt hefur verið fyrir frekari aðgerðir, þar sem aðrar áhættutegundir voru merktar þannig að þær væru ekki til staðar.

Þú verður beðin/n um að tiltaka ráðstafanir fyrir allar áhættutegundir sem svarað var með „nei“ í matsferlinu og forgangsáhættu (óháð því hvort þeim var svarað með jákvæðum eða neikvæðum hætti).

A risk in the action plan.

Þú getur annaðhvort valið af lista með ráðstöfunum, sem kerfið leggur til, eða tiltekið eigin ráðstafanir.

#### Bæta við eigin ráðstöfunum

Adding an extra measure.

Notaðu hnappinn „bæta við ráðstöfun“. Þú ættir að:

- Lýsa þeirri almennu nálgun, sem gripið verður til, til að útrýma eða draga úr áhættunni.
- Taka fram með valkvæðum hætti hvaða á hvaða sérfræðiþekkingu og/eða kröfum sé þörf (t.d. getur þú bætt við hér hvort þörf sé á tiltekinni þjálfun eða utanaðkomandi sérfræðiþekkingu til að taka á áhættunni)
- Færa inn upplýsingar um hver beri ábyrgð á framkvæmdinni.
- Tilgreina fjárhagsramma, ef svo á við.
- Hugsanlega tilgreina dagsetningar um hvenær eigi að hrinda ráðstöfuninni í framkvæmd og hvenær þú ráðgerir að ljúka við hana.

Þú getur bætt við ráðstöfunum eftir þörfum.

#### Bæta við staðlaðri ráðstöfun

Það fer eftir því hvernig landsskrifstofa OiRA/hönnuður verkfærisins setti það upp hvort boðið sé upp á tilgreindar ráðstafanir fyrir einstakar áhættutegundir. Til að velja eina eða fleiri tilgreinda ráðstöfun skaltu smella á hnappinn „velja staðlaða ráðstöfun“.

Sprettivalmynd opnast með öllum ráðstöfununum sem stungið er upp á. Smelltu á hnappinn „bæta við“ hjá þeim sem þú vilt nota.

Tilgreindu ráðstafanirnar birtast þá í aðgerðaáætluninni þinni. Lýsingin á því sem þarf að gera er fastsett en aðra reiti (ábyrgðarsvið, fjárhagsrammi, dagsetningar) er hægt að fylla út og ættir þú að gera það.

Adding standard measures.

Það er hægt að eyða bæði stöðluðum ráðstöfunum og ráðstöfunum, sem þú hefur tiltekið, hvenær sem er.

## Skýrsla

Þegar þú hefur lokið við aðgerðaáætlunina getur þú búið til skýrslu.

Ef þú vilt skilja eftir athugasemd fyrir skýrsluna skaltu skrifa texta hér og vista.

Comment the report.

Sjá hér til að fá frekari upplýsingar um mismunandi skýrslur og hvernig eigi að nota þær.

## Staða

Litla kökuritið í valmyndinni til vinstri sýnir þér framvindu þína í verkfærinu.

Stöðuhlutinn veitir yfirlit yfir hversu margar áhættutegundir þú hefur borið kennsl á, á hversu mörgum þú hefur tekið með ráðstöfunum og hversu mörgum áhættutegundum/fullyrðingum þú hefur enn ekki brugðist við.

The status page.

Þegar þú ferð á stöðuskjámyndina sérðu hversu langt þú hefur náð í hverjum áfanga. Það getur hjálpað þér að skrá niður hvar þú eigir enn eftir að bera kennsl á áhættu eða grípa til ráðstafana þar sem þú hefur greint áhættu.

Scroll to top Load toolbar…
Back

## 3-carrying-out-a-risk-assessment.md

Meira

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More